@@ -424,6 +424,7 @@ class AnalyzeSwaggerClientWrapper:
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
         wait_until_complete: bool = True,
+        model_types: Optional[List[dto.ClassificationModelType]] = None,
     ) -> int:
         payload = dto.CreateClassificationRequest(
             name=name,
@@ -440,6 +441,7 @@ class AnalyzeSwaggerClientWrapper:
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
+            model_types=model_types or UNSET,
         )
 
         model_id = check_exists(
@@ -469,6 +471,7 @@ class AnalyzeSwaggerClientWrapper:
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
         wait_until_complete: bool = True,
+        model_types: Optional[List[dto.RegressionModelType]] = None,
     ) -> int:
         payload = dto.CreateRegressionRequest(
             name=name,
@@ -485,6 +488,7 @@ class AnalyzeSwaggerClientWrapper:
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
+            model_types=model_types or UNSET,
         )
         model_id = check_exists(
             create_regression_model.sync(client=self._client, json_body=payload)
