@@ -4,6 +4,7 @@ import attr
 
 from ....swagger.api.models import create_classification_model
 from ....swagger.models import (
+    ClassificationModelType,
     ClassificationScorers,
     CreateClassificationRequest,
     DataPartitionMethod,
@@ -26,6 +27,7 @@ class InitialConfig:
     number_of_evaluations: int
     nlp_language: NlpLanguage
     draft_mode: bool
+    model_types: Optional[List[ClassificationModelType]]
 
 
 class LocalClassifier(LocalModel):
@@ -81,6 +83,7 @@ class LocalClassifier(LocalModel):
             no_mixing_columns=no_mixing or UNSET,
             partition_column=partition_by or UNSET,
             order_by_column=order_by or UNSET,
+            model_types=self._initial_config.model_types or UNSET,
         )
 
         model_id = check_exists(
