@@ -5,6 +5,7 @@ from ....swagger.models import (
     ModelValidationMethod,
     NlpLanguage,
     ProblemType,
+    RegressionModelType,
     RegressionScorers,
 )
 from ....utils.typing import UNSET, PathLike, Unset
@@ -60,6 +61,7 @@ class AnalyzeRegressor(AnalyzeModel):
         number_of_evaluations: int = 300,
         nlp_language: NlpLanguage = NlpLanguage.AUTO_DETECT,
         draft_mode: bool = False,
+        model_types: Optional[List[RegressionModelType]] = None,
         *,
         connection: Union[ConnectionLike, Unset] = UNSET,
         _internal_model: Union[BaseModel, Unset] = UNSET,
@@ -82,6 +84,7 @@ class AnalyzeRegressor(AnalyzeModel):
                 number_of_evaluations=number_of_evaluations,
                 nlp_language=nlp_language,
                 draft_mode=draft_mode,
+                model_types=model_types,
             )
             super().__init__(_internal_model=LocalRegressor(connection, initial_config))
 
