@@ -5,6 +5,7 @@ from .apply_data_prep_steps_request import ApplyDataPrepStepsRequest
 from .apply_formula_step import ApplyFormulaStep
 from .apply_formula_step_step_type import ApplyFormulaStepStepType
 from .cadence import Cadence
+from .classification_model_type import ClassificationModelType
 from .classification_scorers import ClassificationScorers
 from .combine_step import CombineStep
 from .combine_step_step_type import CombineStepStepType
@@ -105,6 +106,7 @@ from .prediction_response import PredictionResponse
 from .prediction_response_problem_type import PredictionResponseProblemType
 from .prediction_response_task_status import PredictionResponseTaskStatus
 from .problem_type import ProblemType
+from .regression_model_type import RegressionModelType
 from .regression_scorers import RegressionScorers
 from .rename_step import RenameStep
 from .rename_step_step_type import RenameStepStepType
