@@ -5,6 +5,7 @@ import attr
 from ..models.data_partition_method import DataPartitionMethod
 from ..models.model_validation_method import ModelValidationMethod
 from ..models.nlp_language import NlpLanguage
+from ..models.regression_model_type import RegressionModelType
 from ..models.regression_scorers import RegressionScorers
 from ..types import UNSET, Unset
 
@@ -27,6 +28,7 @@ class CreateRegressionRequest:
     no_mixing_columns: Union[Unset, List[str]] = UNSET
     partition_column: Union[Unset, str] = UNSET
     order_by_column: Union[Unset, str] = UNSET
+    model_types: Union[Unset, List[RegressionModelType]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
@@ -63,6 +65,17 @@ class CreateRegressionRequest:
 
         partition_column =  self.partition_column
         order_by_column =  self.order_by_column
+        model_types: Union[Unset, List[Any]] = UNSET
+        if not isinstance(self.model_types, Unset):
+            model_types = []
+            for model_types_item_data in self.model_types:
+                model_types_item = model_types_item_data.value
+
+                model_types.append(model_types_item)
+
+
+
+
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -89,6 +102,8 @@ class CreateRegressionRequest:
             field_dict["partitionColumn"] = partition_column
         if order_by_column is not UNSET:
             field_dict["orderByColumn"] = order_by_column
+        if model_types is not UNSET:
+            field_dict["modelTypes"] = model_types
 
         return field_dict
 
@@ -140,6 +155,16 @@ class CreateRegressionRequest:
 
         order_by_column = d.pop("orderByColumn", UNSET)
 
+        model_types = []
+        _model_types = d.pop("modelTypes", UNSET)
+        for model_types_item_data in (_model_types or []):
+            model_types_item = RegressionModelType(model_types_item_data)
+
+
+
+            model_types.append(model_types_item)
+
+
         create_regression_request = cls(
             name=name,
             data_set_id=data_set_id,
@@ -155,6 +180,7 @@ class CreateRegressionRequest:
             no_mixing_columns=no_mixing_columns,
             partition_column=partition_column,
             order_by_column=order_by_column,
+            model_types=model_types,
         )
 
         create_regression_request.additional_properties = d
